# Generated by Django 5.0.2 on 2024-07-12 17:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('isapilib', '0001_initial'),
    ]

    operations = [
        migrations.DeleteModel(
            name='Agente',
        ),
        migrations.DeleteModel(
            name='Art',
        ),
        migrations.DeleteModel(
            name='Cte',
        ),
        migrations.DeleteModel(
            name='Empresa',
        ),
        migrations.DeleteModel(
            name='Sucursal',
        ),
        migrations.DeleteModel(
            name='TipoOrdenOperacion',
        ),
        migrations.DeleteModel(
            name='Venta',
        ),
        migrations.DeleteModel(
            name='VentaD',
        ),
        migrations.DeleteModel(
            name='Vin',
        ),
        migrations.AddField(
            model_name='apilogs',
            name='status',
            field=models.IntegerField(default=0),
        ),
    ]
