# Generated by Django 5.0.2 on 2024-07-12 17:43

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('isapilib', '0002_delete_agente_delete_art_delete_cte_delete_empresa_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='userapi',
            name='is_admin',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='apilogs',
            name='status',
            field=models.IntegerField(null=True),
        ),
    ]
